@@ -11,7 +11,6 @@
 #include "contacteditor.h"
 #include <Akonadi/CollectionComboBox>
 #include <Akonadi/Item>
-#include <kwidgetsaddons_version.h>
 
 #include <KContacts/Addressee>
 
@@ -178,20 +177,12 @@ AkonadiContactEditor *ContactEditorDialog::editor() const
 void ContactEditorDialog::accept()
 {
     if (d->mEditor->hasNoSavedData()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         const int answer = KMessageBox::questionTwoActions(this,
-#else
-        const int answer = KMessageBox::questionYesNo(this,
-#endif
                                                            i18nc("@info", "Location was not saved. Do you want to close editor?"),
                                                            i18nc("@title:window", "Confirmation"),
                                                            KGuiItem(i18nc("@action:button", "Close Editor"), QStringLiteral("dialog-close")),
                                                            KGuiItem(i18nc("@action:button", "Do Not Close"), QStringLiteral("dialog-cancel")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (answer == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-        if (answer == KMessageBox::No) {
-#endif
             return;
         }
     }
@@ -203,24 +194,15 @@ void ContactEditorDialog::accept()
 
 void ContactEditorDialog::reject()
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const int answer = KMessageBox::questionTwoActions(this,
-#else
-    const int answer = KMessageBox::questionYesNo(this,
-#endif
                                                        i18nc("@info", "Do you really want to cancel?"),
                                                        i18nc("@title:window", "Confirmation"),
                                                        KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
                                                        KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-    if (answer == KMessageBox::Yes) {
-#endif
         QDialog::reject(); // Discard current changes
     }
 }
 
 #include "moc_contacteditordialog.cpp"
-#include <kwidgetsaddons_version.h>
