@@ -17,6 +17,7 @@ using namespace ContactEditor;
 
 PhoneListWidget::PhoneListWidget(QWidget *parent)
     : QWidget(parent)
+    , mPhoneWidgetLister(new ContactEditor::PhoneWidgetLister(this))
 {
     auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
@@ -26,14 +27,11 @@ PhoneListWidget::PhoneListWidget(QWidget *parent)
     label->setObjectName(QStringLiteral("phonelistlabel"));
     topLayout->addWidget(label);
 
-    mPhoneWidgetLister = new ContactEditor::PhoneWidgetLister(this);
     mPhoneWidgetLister->setObjectName(QStringLiteral("phonewidgetlister"));
     topLayout->addWidget(mPhoneWidgetLister);
 }
 
-PhoneListWidget::~PhoneListWidget()
-{
-}
+PhoneListWidget::~PhoneListWidget() = default;
 
 void PhoneListWidget::loadContact(const KContacts::Addressee &contact)
 {
